@@ -6,7 +6,7 @@ use MooseX::Params::Validate;
 
 use List::Util 'max';
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:STEVAN';
 
 # this is a basic type for objects
@@ -42,7 +42,7 @@ has 'version_format' => (is => 'ro', isa => 'Str', default => sub { '%d' });
 
 has '_compiled_name_pattern' => (
     is      => 'ro',
-    isa     => 'Regexp',
+    isa     => 'RegexpRef',
     lazy    => 1,
     default => sub {
         my $self = shift;
@@ -248,7 +248,7 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Infinity Interactive, Inc.
+Copyright 2008-2010 Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
